@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "eager-state" "0.2.2"
+(define-package "eager-state" "20251221.1617"
   "Eagerly persist data onto disk."
   '((emacs "29.1")
     (llama "0.5.0"))
   :url "https://github.com/meedstrom/eager-state"
-  :commit "53282709833021dfbe8605c9eadaa0fffe5da349"
-  :revdesc "0.2.2-0-g532827098330"
+  :commit "7d34fc1f4f341a971ec165fd54b1f42eb9982971"
+  :revdesc "7d34fc1f4f34"
   :keywords '("convenience")
   :authors '(("Martin Edström" . "meedstrom91@gmail.com"))
   :maintainers '(("Martin Edström" . "meedstrom91@gmail.com")))
